@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moo;
 use Term::Size::ReadKey;
@@ -22,11 +22,21 @@ has max_width => (
 	}
 );
 
+has pad => (
+	is => 'rw',
+	default => sub { 0 }
+);
+
 has font => (
 	is => 'rw',
 	default => sub { 'Boomer' }
 );
 
+has align => (
+	is => 'rw',
+	default => sub { 'left' }
+);
+
 has color => (
 	is => 'rw'
 );
@@ -116,10 +126,21 @@ sub new_line {
 
 sub print_line {
 	my ($self, $line) = @_;
+
+	my $line_width = @{$line->[0]};
+	my $pad = $self->align eq 'center' 
+		? ($self->max_width - $line_width) / 2
+		: $self->align eq 'right'
+		? $self->max_width - $line_width
+		: $self->pad;
+
+	$pad = $pad ? " " x $pad : ""; 
+
 	for (@{$line}) {
 		if ($self->color && $self->color_map->{$self->color}) {
 			print $self->color_map->{$self->color};
 		}
+		print $pad;
 		print join "", @{$_};
 		print "\n";
 	}
@@ -135,7 +156,7 @@ Ascii::Text - module for generating ASCII text in various fonts and styles
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -147,7 +168,10 @@ Perhaps a little code snippet.
 
 	use Ascii::Text;
 
-	my $foo = Ascii::Text->new(color => 'red');
+	my $foo = Ascii::Text->new(
+		color => 'red',
+		align => 'center'
+	);
 
 	$foo->("Hello World");
 
@@ -185,12 +209,24 @@ Set/Get the max width of a line of text by default this uses L<Term::Size::ReadK
 
 	$ascii->max_width(100);
 
+=head2 pad
+
+Set/Get the left padding of the text on a line. When "align" is set to center or right this value will become redundant. The default value is 0.
+
+	$ascii->pad(10);
+
 =head2 font
 
 Set/Get the reference to the font class.
 
 	$ascii->font("Boomer");
 
+=head2 align
+
+Set/Get the alignment of the text on the line. Options are left, center or right.
+
+	$ascii->align('right');
+
 =head2 color
 
 Set/Get the font color
